Class: VerifactuRails::IdFactura
- Inherits:
-
Object
- Object
- VerifactuRails::IdFactura
- Defined in:
- lib/verifactu_rails/registro.rb
Overview
Identificación de una factura ajena a la que este registro se refiere: rectificada o sustituida (sf:IDFacturaARType). Son los mismos tres campos que identifican cualquier factura, sin la huella.
Instance Attribute Summary collapse
-
#fecha_expedicion ⇒ Object
readonly
Returns the value of attribute fecha_expedicion.
-
#id_emisor ⇒ Object
readonly
Returns the value of attribute id_emisor.
-
#num_serie ⇒ Object
readonly
Returns the value of attribute num_serie.
Instance Method Summary collapse
- #a_pares ⇒ Object
-
#initialize(id_emisor:, num_serie:, fecha_expedicion:) ⇒ IdFactura
constructor
A new instance of IdFactura.
Constructor Details
#initialize(id_emisor:, num_serie:, fecha_expedicion:) ⇒ IdFactura
Returns a new instance of IdFactura.
59 60 61 62 63 |
# File 'lib/verifactu_rails/registro.rb', line 59 def initialize(id_emisor:, num_serie:, fecha_expedicion:) @id_emisor = Formato.nif(id_emisor, 'IDEmisorFactura') @num_serie = Formato.num_serie(num_serie) @fecha_expedicion = Formato.fecha(fecha_expedicion) end |
Instance Attribute Details
#fecha_expedicion ⇒ Object (readonly)
Returns the value of attribute fecha_expedicion.
57 58 59 |
# File 'lib/verifactu_rails/registro.rb', line 57 def fecha_expedicion @fecha_expedicion end |
#id_emisor ⇒ Object (readonly)
Returns the value of attribute id_emisor.
57 58 59 |
# File 'lib/verifactu_rails/registro.rb', line 57 def id_emisor @id_emisor end |
#num_serie ⇒ Object (readonly)
Returns the value of attribute num_serie.
57 58 59 |
# File 'lib/verifactu_rails/registro.rb', line 57 def num_serie @num_serie end |
Instance Method Details
#a_pares ⇒ Object
65 66 67 68 |
# File 'lib/verifactu_rails/registro.rb', line 65 def a_pares { 'IDEmisorFactura' => id_emisor, 'NumSerieFactura' => num_serie, 'FechaExpedicionFactura' => fecha_expedicion } end |