Class: VerifactuRails::RespuestaConsulta::Anotado
- Inherits:
-
Struct
- Object
- Struct
- VerifactuRails::RespuestaConsulta::Anotado
- Defined in:
- lib/verifactu_rails/consulta.rb
Overview
Un registro tal y como la AEAT lo tiene guardado.
Instance Attribute Summary collapse
-
#codigo_error ⇒ Object
Returns the value of attribute codigo_error.
-
#cuota_total ⇒ Object
Returns the value of attribute cuota_total.
-
#descripcion_error ⇒ Object
Returns the value of attribute descripcion_error.
-
#estado ⇒ Object
Returns the value of attribute estado.
-
#fecha_expedicion ⇒ Object
Returns the value of attribute fecha_expedicion.
-
#fecha_hora_gen ⇒ Object
Returns the value of attribute fecha_hora_gen.
-
#huella ⇒ Object
Returns the value of attribute huella.
-
#huella_anterior ⇒ Object
Returns the value of attribute huella_anterior.
-
#id_emisor ⇒ Object
Returns the value of attribute id_emisor.
-
#importe_total ⇒ Object
Returns the value of attribute importe_total.
-
#num_serie ⇒ Object
Returns the value of attribute num_serie.
-
#num_serie_anterior ⇒ Object
Returns the value of attribute num_serie_anterior.
-
#numero_instalacion ⇒ Object
Returns the value of attribute numero_instalacion.
-
#primer_registro ⇒ Object
Returns the value of attribute primer_registro.
-
#subsanacion ⇒ Object
Returns the value of attribute subsanacion.
-
#timestamp_modificacion ⇒ Object
Returns the value of attribute timestamp_modificacion.
-
#tipo_factura ⇒ Object
Returns the value of attribute tipo_factura.
Instance Method Summary collapse
- #aceptado_con_errores? ⇒ Boolean
-
#anulado? ⇒ Boolean
La factura fue anulada por un registro de anulación posterior.
- #correcto? ⇒ Boolean
- #primer_registro? ⇒ Boolean
- #subsanacion? ⇒ Boolean
- #to_s ⇒ Object
Instance Attribute Details
#codigo_error ⇒ Object
Returns the value of attribute codigo_error
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def codigo_error @codigo_error end |
#cuota_total ⇒ Object
Returns the value of attribute cuota_total
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def cuota_total @cuota_total end |
#descripcion_error ⇒ Object
Returns the value of attribute descripcion_error
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def descripcion_error @descripcion_error end |
#estado ⇒ Object
Returns the value of attribute estado
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def estado @estado end |
#fecha_expedicion ⇒ Object
Returns the value of attribute fecha_expedicion
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def fecha_expedicion @fecha_expedicion end |
#fecha_hora_gen ⇒ Object
Returns the value of attribute fecha_hora_gen
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def fecha_hora_gen @fecha_hora_gen end |
#huella ⇒ Object
Returns the value of attribute huella
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def huella @huella end |
#huella_anterior ⇒ Object
Returns the value of attribute huella_anterior
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def huella_anterior @huella_anterior end |
#id_emisor ⇒ Object
Returns the value of attribute id_emisor
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def id_emisor @id_emisor end |
#importe_total ⇒ Object
Returns the value of attribute importe_total
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def importe_total @importe_total end |
#num_serie ⇒ Object
Returns the value of attribute num_serie
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def num_serie @num_serie end |
#num_serie_anterior ⇒ Object
Returns the value of attribute num_serie_anterior
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def num_serie_anterior @num_serie_anterior end |
#numero_instalacion ⇒ Object
Returns the value of attribute numero_instalacion
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def numero_instalacion @numero_instalacion end |
#primer_registro ⇒ Object
Returns the value of attribute primer_registro
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def primer_registro @primer_registro end |
#subsanacion ⇒ Object
Returns the value of attribute subsanacion
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def subsanacion @subsanacion end |
#timestamp_modificacion ⇒ Object
Returns the value of attribute timestamp_modificacion
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def @timestamp_modificacion end |
#tipo_factura ⇒ Object
Returns the value of attribute tipo_factura
165 166 167 |
# File 'lib/verifactu_rails/consulta.rb', line 165 def tipo_factura @tipo_factura end |
Instance Method Details
#aceptado_con_errores? ⇒ Boolean
172 |
# File 'lib/verifactu_rails/consulta.rb', line 172 def aceptado_con_errores? = estado == 'AceptadoConErrores' |
#anulado? ⇒ Boolean
La factura fue anulada por un registro de anulación posterior. Este estado NO existe en la respuesta al envío.
176 |
# File 'lib/verifactu_rails/consulta.rb', line 176 def anulado? = estado == 'Anulado' |
#correcto? ⇒ Boolean
171 |
# File 'lib/verifactu_rails/consulta.rb', line 171 def correcto? = estado == 'Correcto' |
#primer_registro? ⇒ Boolean
179 |
# File 'lib/verifactu_rails/consulta.rb', line 179 def primer_registro? = primer_registro == 'S' |
#subsanacion? ⇒ Boolean
178 |
# File 'lib/verifactu_rails/consulta.rb', line 178 def subsanacion? = subsanacion == 'S' |
#to_s ⇒ Object
181 182 183 184 185 |
# File 'lib/verifactu_rails/consulta.rb', line 181 def to_s base = "#{num_serie}: #{estado}" base += ' (subsanación)' if subsanacion? codigo_error ? "#{base} [#{codigo_error}] #{descripcion_error}" : base end |